Module ast_extract

Module ast_extract 

Regex-based AST extraction engine.

This module implements a working regex-based extractor for each supported language. It serves as the “Pass 1” deterministic extraction while tree-sitter grammar crates are being added to the workspace.

For each source file the extractor produces:

  • A file node
  • Class / struct / trait / interface nodes
  • Function / method nodes with defines edges from their parent
  • Import nodes with imports edges from the file
  • Calls edges inferred by matching known function names within bodies

Functions

extract_file
Extract graph nodes and edges from a single source file.