pub fn extract_file(path: &Path, source: &str, lang: &str) -> ExtractionResultExpand description
Extract graph nodes and edges from a single source file.
pub fn extract_file(path: &Path, source: &str, lang: &str) -> ExtractionResultExtract graph nodes and edges from a single source file.