pub struct LanguageConfig {
pub name: &'static str,
pub ts_crate: &'static str,
pub class_types: HashSet<&'static str>,
pub function_types: HashSet<&'static str>,
pub import_types: HashSet<&'static str>,
pub call_types: HashSet<&'static str>,
pub name_field: &'static str,
pub body_field: &'static str,
pub call_function_field: &'static str,
pub function_boundary_types: HashSet<&'static str>,
pub function_label_parens: bool,
}Expand description
Metadata describing how to extract entities from a language’s AST.
Fields
name: &'static strHuman-readable language name.
ts_crate: &'static strCrate that provides the tree-sitter grammar (e.g. "tree_sitter_python").
class_types: HashSet<&'static str>AST node types that represent class-like definitions.
function_types: HashSet<&'static str>AST node types that represent function/method definitions.
import_types: HashSet<&'static str>AST node types that represent import statements.
call_types: HashSet<&'static str>AST node types that represent function calls.
name_field: &'static strField name for the entity name within the AST node.
body_field: &'static strField name for the body of a class/function.
call_function_field: &'static strField name for the function being called in a call expression.
function_boundary_types: HashSet<&'static str>AST node types that delimit function boundaries (for scope analysis).
function_label_parens: boolWhether the language uses parenthesised labels (e.g. Go func (r *Recv) Name()).