Module treesitter

Module treesitter 

Tree-sitter based AST extraction engine.

Provides accurate structural extraction using native tree-sitter grammars for Python, JavaScript, TypeScript, Rust, Go, Java, C, C++, Ruby, and C#. Falls back gracefully to the regex-based extractor for unsupported languages.

Structs

TsConfig
Describes which tree-sitter node kinds correspond to classes, functions, imports and calls for a given language.

Functions

try_extract
Try tree-sitter extraction for a supported language. Returns None if the language is not supported by tree-sitter grammars.