pub struct TsConfig {
pub class_types: HashSet<&'static str>,
pub function_types: HashSet<&'static str>,
pub import_types: HashSet<&'static str>,
pub call_types: HashSet<&'static str>,
pub name_field: &'static str,
pub class_name_field: Option<&'static str>,
pub body_field: &'static str,
pub call_function_field: &'static str,
}Expand description
Describes which tree-sitter node kinds correspond to classes, functions, imports and calls for a given language.
Fields
class_types: HashSet<&'static str>function_types: HashSet<&'static str>import_types: HashSet<&'static str>call_types: HashSet<&'static str>name_field: &'static strField name used by the grammar to expose the identifier of a definition.
class_name_field: Option<&'static str>Optional override for class/struct name field (defaults to name_field).
body_field: &'static strField name for the body block of a class/function.
call_function_field: &'static strField name inside a call expression that points to the callee.